package com.fzm.portal.controller;

import com.fasterxml.jackson.databind.deser.std.NumberDeserializers;
import com.fzm.common.annotation.Authentication;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.utils.OssUtil;
import com.tencentcloudapi.tsf.v20180326.models.TaskRule;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.Map;

/**
 * @author tangtuo
 * @date 2021/7/13 10:34
 */
@RestController
@RequestMapping("/oss")
@Api(tags = "oss相关")
public class OssController {

    @Resource
    private OssUtil ossUtil;

    @Authentication
    @GetMapping("/policy")
    @ApiOperation("完成oss签名")
    public ResponseModel<Map<String, String>> policy() {
        Map<String, String> policy = ossUtil.policy();
        return ResponseModel.success(policy);
    }

    @Authentication
    @PostMapping("/upload")
    @ApiOperation("普通文件上传")
    public ResponseModel<String> upload(MultipartFile file) throws IOException {
        return ResponseModel.success(ossUtil.putSimpleObject(file));
    }


    @Authentication
    @PostMapping("/download")
    @ApiOperation(value = "下载文件")
    public void download(@RequestParam String fileUrl) {
        String fileName = fileUrl.substring(fileUrl.lastIndexOf("/") + 1);
        ossUtil.downloadFile(fileUrl, fileName);
    }


    @Authentication
    @ApiOperation(value = "删除文件")
    @PostMapping(value = "/delete")
    public ResponseModel<Boolean> delete(String fileUrl) {
        ossUtil.delete(fileUrl);
        return ResponseModel.success(true);
    }
}
